@@ -4,7 +4,7 @@ package App::ElasticSearch::Utilities::Query;
 use strict;
 use warnings;
 
-our $VERSION = '7.3'; # VERSION
+our $VERSION = '7.4'; # VERSION
 
 use CLI::Helpers qw(:output);
 use Clone qw(clone);
@@ -19,6 +19,13 @@ my %TO = (
 );
 
 
+has fields_meta => (
+    is => 'rw',
+    isa => HashRef,
+    default => sub { {} },
+);
+
+
 has query_stash => (
     is       => 'rw',
     isa      => HashRef,
@@ -276,10 +283,14 @@ App::ElasticSearch::Utilities::Query - Object representing ES Queries
 
 =head1 VERSION
 
-version 7.3
+version 7.4
 
 =head1 ATTRIBUTES
 
+=head2 fields_meta
+
+A hash reference with the field data from L<App::ElasticSearch::Utilities::es_index_fields>.
+
 =head2 query_stash
 
 Hash reference containing replaceable query elements.  See L<stash>.
